abacusai.range_violation — AbacusAI documentation

# `abacusai.range_violation`

## Module Contents

### Classes

`RangeViolation` | Summary of important range mismatches for a numerical feature discovered by a model monitoring instance

class abacusai.range_violation.RangeViolation(client, name=None, trainingMin=None, trainingMax=None, predictionMin=None, predictionMax=None, freqAboveTrainingRange=None, freqBelowTrainingRange=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important range mismatches for a numerical feature discovered by a model monitoring instance

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - trainingMin (float) – Minimum value of training distribution for the specified feature.

    - trainingMax (float) – Maximum value of training distribution for the specified feature.

    - predictionMin (float) – Minimum value of prediction distribution for the specified feature.

    - predictionMax (float) – Maximum value of prediction distribution for the specified feature.

    - freqAboveTrainingRange (float) – Frequency of prediction rows below training minimum for the specified feature.

    - freqBelowTrainingRange (float) – Frequency of prediction rows above training maximum for the specified feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict